@@ -51,7 +51,7 @@ try {
     $ExtQuery->setSortOrder($sortOrder);
     $ExtQuery->type = $App->getSession('searchMaskState');
 
-    $App->setSession('isSpam',$extForm['isSpam']);
+    $App->setSession('isSpam',@$extForm['isSpam']);
 
     // reset simple query
     $SimpleQuery = new Query('empty');
