@@ -54,7 +54,7 @@ $ExtQuery = new Query($queryId,$archive,
 $ExtQuery->type = $searchMaskState;
 $ExtQuery->setSortOrder($sortOrder);
 
-$App->setSession('isSpam',$extForm['isSpam']);
+$App->setSession('isSpam',@$extForm['isSpam']);
 
 try {
     // store query
