@@ -52,8 +52,8 @@ class Benno
      */
     function __construct()
     {
-        $this->infoText = 'Benno MailArchiv Version 2.8.19-1'; 
-        $this->buildInfo= '221214103916/010c6b3';
+        $this->infoText = 'Benno MailArchiv Version 2.8.20'; 
+        $this->buildInfo= '221222191416/97576fa';
         $this->buildYear= '2022';
     }
 
