@@ -229,6 +229,16 @@ class User extends UserDA
         sort($this->archive);
     }
 
+    // Return username suffix after first "@"
+    function getIdSuffix ()  {
+        $sfx = '';
+        if (strstr($this->id,'@')) {
+            list ($pfx,$sfx) = explode('@',$this->id,2);
+        }
+
+        return $sfx;
+    }
+
     function getAuthParam ($param) { return $this->authparam[$param]; }
 
     function getAdresses () { return $this->adresses; }
