@@ -54,23 +54,30 @@ if (!$USER->hasArchive($archive)) {
 
 // bild path for REST request
 $rest_path = ltrim($_SERVER['PATH_INFO'],'/');
+$url = $base_url.'/'.$rest_path.'/';
+
+$query_data = $_REQUEST;
 
 // mailadress filter
 $FilterList = Filter::FetchList($USER);
-$filterString = '';
 foreach ($FilterList as $Filter) {
-    $filterString .= $Filter->getString();
+    $user_filter = $Filter->getString();
+    $user_filter = preg_replace('/\s/','%20',$user_filter);
 }
-$filterString = preg_replace('/\s/','%20',$filterString);
 
-$query_request = $_SERVER['QUERY_STRING'];
-$query_request = preg_replace('/[\&]?\bfilterQuery=[^\&]+/','',$query_request);
-$filterQuery   = 'filterQuery='.$filterString;
-$query_request = $filterQuery.'&'.$archive.'&'.$query_request;
-$App->log("Query request: $query_request",4,'rest_backend');
+$user_role = $USER->getRole();
+if ($user_role != 'ADMIN') {
+    // unprivileged user
+    $query_filter = 'filterQuery='.$user_filter;
+}
+else if (!$query_data['filterQuery']) {
+    // ADMIN user
+    $query_filter = 'filterQuery='.$user_filter;
+}
+
+$backend_query = $query_filter.'&'.http_build_query($query_data);
+$App->log("Query request: $backend_query",4,'rest_backend');
 
-// remove possible filter entries from query
-$url = $base_url.'/'.$rest_path.'/';
 
 // Open the cURL session
 $curl = curl_init();
@@ -79,7 +86,7 @@ curl_setopt($curl, CURLOPT_URL, $url);
 curl_setopt($curl, CURLOPT_HEADER, 1);
 curl_setopt($curl, CURLOPT_USERPWD, $rest_user.':'.$rest_pass);
 curl_setopt($curl, CURLOPT_POST, 1);
-curl_setopt($curl, CURLOPT_POSTFIELDS, $query_request);
+curl_setopt($curl, CURLOPT_POSTFIELDS, $backend_query);
 
 curl_setopt($curl, CURLOPT_RETURNTRANSFER,1);
 curl_setopt($curl, CURLOPT_TIMEOUT,30);
@@ -101,14 +108,6 @@ if (preg_match('/^https:/',$url)) {
 // suppress using of 100-Continue requests
 curl_setopt($curl, CURLOPT_HTTPHEADER,array("Expect:"));
 
-if($_SERVER['REQUEST_METHOD'] == 'POST'){
-	curl_setopt($curl, CURLOPT_POST, 1);
-    // !!! request must be send as  (could be changed in future) !!!
-    //  Content-Type: application/x-www-form-urlencoded
-    $post_data = http_build_query($_POST);
-	curl_setopt($curl, CURLOPT_POSTFIELDS, $post_data);
-}
-
 // prepare request debugging
 $loglevel = $App->loglevelForModule('rest_backend');
 if ($loglevel >= 2) {
